/**
 * @file
 *
 * @brief
 *
 * @copyright BSD License (see doc/COPYING or http://www.libelektra.org)
 */

#include "confignodetest.hpp"

ConfigNodeTest::ConfigNodeTest (QObject * parent) : QObject (parent)
{
}
